@@ -6,3 +6,6 @@ pub use simple::SimpleBar;
 
 pub mod spinny;
 pub use spinny::SpinniBuilder;
+
+pub mod custom;
+pub use custom::CustomBar;
