@@ -1,13 +1,13 @@
-mod threaded_wrapper;
 mod basic_wrapper;
+mod threaded_wrapper;
 
 use std::fmt::Debug;
 use std::ops::DerefMut;
 
 use crate::IsBar;
 
-pub use threaded_wrapper::ThreadedBarWrapper;
 pub use basic_wrapper::BarWrapper;
+pub use threaded_wrapper::ThreadedBarWrapper;
 
 /// General API for a bar wrappers used by [`ThreadedBarWrapper`] and [`BarWrapper`]
 #[allow(clippy::module_name_repetitions)]
@@ -17,7 +17,7 @@ pub trait IsBarWrapper: crate::sealant::Sealed {
     type Error: Debug;
     // *screams*
     /// Attempts to aqquire the contained bar
-    /// 
+    ///
     /// # Errors
     /// if there is some error aqquiring the bar
     fn try_bar<'b>(&'b mut self)
@@ -27,7 +27,7 @@ pub trait IsBarWrapper: crate::sealant::Sealed {
     ///
     /// # Panics
     /// if aqquiring the bar fails.
-    /// 
+    ///
     /// for a non-panicking version, see [`try_bar`]
     ///
     /// [`try_bar`]: IsBarWrapper::try_bar
@@ -42,24 +42,25 @@ pub trait IsBarWrapper: crate::sealant::Sealed {
 pub trait IsBarWrapper: crate::sealant::Sealed {
     type Bar: IsBar;
     type Error: Debug;
-    type BarGuard<'g>: DerefMut<Target = Self::Bar> where Self: 'g;
+    type BarGuard<'g>: DerefMut<Target = Self::Bar>
+    where
+        Self: 'g;
     // *screams*
     /// Attempts to aqquire the contained bar
-    /// 
+    ///
     /// # Errors
     /// if there is some error aqquiring the bar
     fn try_bar<'g>(&'g mut self) -> Result<Self::BarGuard<'g>, Self::Error>;
 
-
     /// Gets a reference to the underlying bar for calling functions on it
     ///
     /// # Panics
     /// if aqquiring the bar fails.
-    /// 
+    ///
     /// for a non-panicking version, see [`try_bar`]
     ///
     /// [`try_bar`]: IsBarWrapper::try_bar
     fn bar<'g>(&'g mut self) -> Self::BarGuard<'g> {
         self.try_bar().unwrap()
     }
-}
\ No newline at end of file
+}
